<?php
/*
* 2007-2016 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2016 PrestaShop SA
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_CAN_LOAD_FILES_')) {
    exit;
}

use PrestaShop\PrestaShop\Core\Module\WidgetInterface;

class Ps_Homeyoutube extends Module implements WidgetInterface
{
    private $templateFile;

    public function __construct()
    {
        $this->name = 'ps_homeyoutube';
        $this->author = 'John Doe';
        $this->version = '0.2.0';

        $this->bootstrap = true;
        parent::__construct();

        $this->displayName = $this->trans('YouTube video on the main page', array(), 'Modules.Homeyoutube.Admin');
        $this->description = $this->trans('Adds a video from YouTube to the main page of the site.', array(), 'Modules.Homeyoutube.Admin');

        $this->ps_versions_compliancy = array('min' => '1.7.1.0', 'max' => _PS_VERSION_);

        $this->templateFile = 'module:ps_homeyoutube/ps_homeyoutube.tpl';
    }

    public function install()
    {
        return (parent::install() &&
            Configuration::updateValue('HOME_YOUTUBE', 'https://www.youtube.com/embed/ThGwmdYKXE0?autoplay=1&amp;loop=1;playlist=ThGwmdYKXE0') &&
            $this->registerHook('displayHeader') &&
            $this->registerHook('displayHome'));
    }

    public function uninstall()
    {
        return (Configuration::deleteByName('HOME_YOUTUBE') &&
            parent::uninstall());
    }

    public function getContent()
    {
        if (Tools::isSubmit('submitModule')) {
            Configuration::updateValue('HOME_YOUTUBE', Tools::getValue('home_youtube', ''));

            $this->_clearCache('*');

            Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules').'&configure='.$this->name.'&tab_module='.$this->tab.'&conf=4&module_name='.$this->name);
        }

        return $this->renderForm();
    }

    public function _clearCache($template, $cache_id = null, $compile_id = null)
    {
        parent::_clearCache($this->templateFile);
    }

    public function renderForm()
    {
        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->trans('Settings', array(), 'Admin.Global'),
                    'icon' => 'icon-cogs'
                ),
                'input' => array(
                    array(
                        'type' => 'text',
                        'label' => $this->trans('YouTube URL', array(), 'Modules.Homeyoutube.Admin'),
                        'name' => 'home_youtube',
                        'desc' => $this->trans('eg. https://www.youtube.com/embed/ThGwmdYKXE0', array(), 'Modules.Homeyoutube.Admin'),
                    ),
                ),
                'submit' => array(
                    'title' => $this->trans('Save', array(), 'Admin.Global'),
                )
            ),
        );

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table =  $this->table;
        $helper->submit_action = 'submitModule';
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFieldsValues(),
        );

        return $helper->generateForm(array($fields_form));
    }

    public function getConfigFieldsValues()
    {
        return array(
            'home_youtube' => Tools::getValue('home_youtube', Configuration::get('HOME_YOUTUBE')),
        );
    }

    public function renderWidget($hookName = null, array $configuration = [])
    {
        if (!$this->isCached($this->templateFile, $this->getCacheId('ps_homeyoutube'))) {
            $this->smarty->assign($this->getWidgetVariables($hookName, $configuration));
        }

        return $this->fetch($this->templateFile, $this->getCacheId('ps_homeyoutube'));
    }

    public function getWidgetVariables($hookName = null, array $configuration = [])
    {
        $youtube_links = array();

        if ($sf_youtube = Configuration::get('HOME_YOUTUBE')) {
            $youtube_links['youtube'] = array(
                'url' => $sf_youtube,
            );
        }

        return array(
            'youtube_links' => $youtube_links,
        );
    }
    
    public function hookdisplayHeader($params)
    {
        $this->context->controller->registerStylesheet('modules-homeyoutube', 'modules/'.$this->name.'/css/ps_homeyoutube.css', ['media' => 'all', 'priority' => 150]);
    }    
}
